

import stripe
from stripe.error import AuthenticationError
from django.conf import settings

from .helpers import color as c
from .models import StripeConfig


SILLY_STRIPE = {
    'is_configured': False,
    'STRIPE_PUBLIC_KEY': None,
    'STRIPE_SECRET_KEY': None,
    'STRIPE_WEBHOOK_SECRET': None,
}

for key in settings.SILLY_STRIPE:
    SILLY_STRIPE[key] = settings.SILLY_STRIPE[key]


if SILLY_STRIPE['config_name'] is not None and \
        StripeConfig.objects.filter(name=SILLY_STRIPE['config_name']).exists():
    stripe_config = StripeConfig.objects.get(name=SILLY_STRIPE['config_name'])
    stripe.api_key = stripe_config.secret_key
    SILLY_STRIPE['is_configured'] = True

    print('=== Customers: ', stripe.Customer.list())
    print('=== Products: ', stripe.Product.list())

else:
    print(f"{c['warning']}DJANGO-SILLY-STRIPE IS NOT CONFIGURED{c['end']}")



from django.contrib import admin
from .models import StripeConfig


class StripeConfigAdmin(admin.ModelAdmin):
    list_display = ('name',)
    list_display_links = ('name',)


admin.site.register(StripeConfig, StripeConfigAdmin)




# color parameters: style;background (30 is none);foreground

color = {
    "end": "\x1b[0m",
    "info": "\x1b[0;30;36m",
    "success": "\x1b[0;30;32m",
    "warning": "\x1b[0;30;33m",
    "danger": "\x1b[0;30;31m",
}



import uuid

from django.db import models


class StripeConfig(models.Model):
    id = models.UUIDField(
        primary_key=True,
        default=uuid.uuid4,
        editable=False,
    )
    name = models.CharField(max_length=100, unique=True)
    public_key = models.CharField(max_length=255)
    secret_key = models.CharField(max_length=255)
    restricted_key = models.CharField(max_length=255, null=True, blank=True)
    webhook_secret = models.CharField(max_length=255, null=True, blank=True)

    class Meta:
        verbose_name = "Stripe config"
        verbose_name_plural = "Stripe configs"

    def __str__(self):
        return f"<StripeConfig: {self.name}>"
